@@ -15,9 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: buffer.h,v 1.162 2007/01/14 16:53:37 klan Exp $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  *
  *
  * contents:
@@ -28,7 +26,6 @@
  * free buffer pool management routines
  *
  * FIFO buffer structures/routines
- *
  */
 
 #ifndef HAVE_BUFFER_H
@@ -192,6 +189,8 @@ extern "C" {
 #define BUF_VIDEO_CAVS		0x02620000
 #define BUF_VIDEO_VP6F		0x02630000
 #define BUF_VIDEO_THEORA_RAW	0x02640000
+#define BUF_VIDEO_VC1		0x02650000
+#define BUF_VIDEO_VMNC		0x02660000
 
 /* audio buffer types:  (please keep in sync with buffer_types.c) */
 
@@ -259,6 +258,7 @@ extern "C" {
 #define BUF_AUDIO_SMACKER	0x033B0000
 #define BUF_AUDIO_FLVADPCM	0x033C0000
 #define BUF_AUDIO_WAVPACK	0x033D0000
+#define BUF_AUDIO_MP3ADU	0x033E0000
 
 /* spu buffer types:    */
 
